# Pasee — Identity Managment Server

[![Documentation Status](https://readthedocs.org/projects/pasee/badge/?version=latest)](https://pasee.readthedocs.io/en/latest/?badge=latest)
[![Package on PyPI](https://img.shields.io/pypi/v/pasee.svg)](https://pypi.org/project/pasee/)
[![Build status](https://travis-ci.org/meltygroup/pasee.svg?branch=master)](https://travis-ci.org/meltygroup/pasee)


Pasee is a simple layer over multiple IdMs, typically a Kisee
and other identity providers like Twitter, Github, …

Documentation: [https://pasee.readthedocs.io](https://pasee.readthedocs.io)
